@@ -1,4 +1,4 @@
-# $Revision: 1.11 $$Date: 2004/01/27 18:59:22 $$Author: wsnyder $
+# $Revision: 1.14 $$Date: 2004/08/26 15:04:20 $$Author: ws150726 $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -17,7 +17,7 @@ package P4::C4::File;
 use DirHandle;
 use strict;
 
-our $VERSION = '2.021';
+our $VERSION = '2.030';
 
 sub new {
     my $class = shift;
@@ -91,16 +91,20 @@ P4::C4::File - Information on one C4 tracked file
 
 This module is for internal P4::C4 use.
 
-=head1 SEE ALSO
-
-C<P4::C4>, 
-
 =head1 DISTRIBUTION
 
-The latest version is available from CPAN.
+The latest version is available from CPAN and from L<http://www.veripool.com/>.
+
+Copyright 2002-2004 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+L<P4::C4>
+
 =cut
