@@ -1,4 +1,4 @@
-# $Revision: 1.9 $$Date: 2004/01/27 18:59:22 $$Author: wsnyder $
+# $Revision: 1.12 $$Date: 2004/08/26 15:04:20 $$Author: ws150726 $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -20,7 +20,7 @@ use strict;
 require Exporter;
 our @ISA = ('Exporter');
 our @EXPORT = qw( fileNoLinks );
-our $VERSION = '2.021';
+our $VERSION = '2.030';
 
 ######################################################################
 
@@ -109,16 +109,20 @@ Resolve any symlinks in the given filename.
 
 =back
 
-=head1 SEE ALSO
-
-C<P4::C4>, 
-
 =head1 DISTRIBUTION
 
-The latest version is available from CPAN.
+The latest version is available from CPAN and from L<http://www.veripool.com/>.
+
+Copyright 2002-2004 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+L<P4::C4>
+
 =cut
