@@ -1,4 +1,4 @@
-# $Revision: 1.11 $$Date: 2004/01/27 18:59:22 $$Author: wsnyder $
+# $Revision: 1.14 $$Date: 2004/08/26 15:04:20 $$Author: ws150726 $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -19,7 +19,7 @@ use strict;
 use vars qw($VERSION);
 our @ISA = qw( P4::UI );
 
-$VERSION = '2.021';
+$VERSION = '2.030';
 
 sub new {
     my $class = shift;
@@ -69,16 +69,20 @@ user interface client, but supports hashed arguments in the new
 constructor.  It's default callbacks die on errors instead of just printing
 them.
 
-=head1 SEE ALSO
-
-C<P4::UI>, C<P4::C4>, 
-
 =head1 DISTRIBUTION
 
-The latest version is available from CPAN.
+The latest version is available from CPAN and from L<http://www.veripool.com/>.
+
+Copyright 2002-2004 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+L<P4::UI>, L<P4::C4>
+
 =cut
